iamai.adapter.cqhttp.cqhttp.exceptions module
=============================================

.. automodule:: iamai.adapter.cqhttp.cqhttp.exceptions
   :members:
   :undoc-members:
   :show-inheritance:
